==> redux-schema-4.4.2.tgz: package/es/types/error.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import finalizeType from '../parse/finalize-type';
import { pathToStr, isPlainObject } from '../utils';
import serializeError from 'serialize-error';

export default function error(options) {
  var name = pathToStr(options.typeMoniker) || 'error';

  return finalizeType({
    isType: true,
    name: name,
    kind: 'error',
    storageKinds: ['object'],
    options: options,
    validateData: function validateData(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!isPlainObject(value) || typeof value.name !== 'string' || typeof value.message !== 'string') {
        return 'Type of "' + (pathToStr(instancePath) || name) + '" data must be and Error object';
      }
    },
    validateAssign: function validateAssign(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!(value instanceof Error)) {
        return 'Type of "' + (pathToStr(instancePath) || name) + '" must be Error';
      }
    },
    pack: function pack(value) {
      var serializable = JSON.parse(JSON.stringify(serializeError(value)));
      if (serializable.stack) {
        serializable.stack = serializable.stack.split('\n');
      }
      return serializable;
    },
    unpack: function unpack(store, path, instancePath, currentInstance) {
      if (currentInstance) throw new Error('Error types cannot modify a data instance');
      var value = _extends({}, store.get(path)),
          type = {
        EvalError: EvalError,
        RangeError: RangeError,
        ReferenceError: ReferenceError,
        SyntaxError: SyntaxError,
        TypeError: TypeError,
        URIError: URIError
      }[value.name] || Error;

      if (value.stack && value.stack.join) {
        value.stack = value.stack.join('\n');
      }
      if (type.prototype.name === value.name) {
        delete value.name;
      }

      return _extends(Object.create(type.prototype), _extends({}, value, {
        toString: function toString() {
          return this.message ? this.name + ': ' + this.message : this.name;
        },
        inspect: function inspect() {
          return '[' + this.toString() + ']';
        }
      }));
    },
    getTypeFromPath: function getTypeFromPath(path) {
      if (path.length) throw new Error('Cannot get type path for properties of Errors');
      return options.typeMoniker;
    },
    defaultValue: function defaultValue() {
      return {
        name: 'Error',
        message: ''
      };
    }
  });
}

==> redux-schema-4.8.0.tgz: package/es/types/error.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import finalizeType from '../parse/finalize-type';
import { pathToStr, isPlainObject } from '../utils';
import serializeError from 'serialize-error';

export default function error(options) {
  var name = pathToStr(options.typeMoniker) || 'error';

  var thisType = finalizeType({
    isType: true,
    name: name,
    kind: 'error',
    storageKinds: ['object'],
    options: options,
    validateData: function validateData(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!isPlainObject(value) || typeof value.name !== 'string' || typeof value.message !== 'string') {
        return 'Type of "' + (pathToStr(instancePath) || name) + '" data must be and Error object';
      }
    },
    coerceData: function coerceData(value, instancePath) {
      if (!thisType.validateData(value, instancePath)) return value;
      return thisType.defaultValue();
    },
    validateAssign: function validateAssign(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!(value instanceof Error)) {
        return 'Type of "' + (pathToStr(instancePath) || name) + '" must be Error';
      }
    },
    pack: function pack(value) {
      var serializable = JSON.parse(JSON.stringify(serializeError(value)));
      if (serializable.stack) {
        serializable.stack = serializable.stack.split('\n');
      }
      return serializable;
    },
    unpack: function unpack(store, path, instancePath, currentInstance) {
      if (currentInstance) throw new Error('Error types cannot modify a data instance');
      var value = _extends({}, store.get(path)),
          type = {
        EvalError: EvalError,
        RangeError: RangeError,
        ReferenceError: ReferenceError,
        SyntaxError: SyntaxError,
        TypeError: TypeError,
        URIError: URIError
      }[value.name] || Error;

      if (value.stack && value.stack.join) {
        value.stack = value.stack.join('\n');
      }
      if (type.prototype.name === value.name) {
        delete value.name;
      }

      return _extends(Object.create(type.prototype), _extends({}, value, {
        toString: function toString() {
          return this.message ? this.name + ': ' + this.message : this.name;
        },
        inspect: function inspect() {
          return '[' + this.toString() + ']';
        }
      }));
    },
    getTypeFromPath: function getTypeFromPath(path) {
      if (path.length) throw new Error('Cannot get type path for properties of Errors');
      return options.typeMoniker;
    },
    defaultValue: function defaultValue() {
      return {
        name: 'Error',
        message: ''
      };
    }
  });

  return thisType;
}
